@@ -17,6 +17,10 @@
  * USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "cscmi.h"
 #include "sol.h"
 #include "slot.h"
