@@ -17,7 +17,10 @@
  * USA
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <guile/gh.h>
 #include <dirent.h>
@@ -210,7 +213,7 @@ void show_hint_dialog()
       case 1:
 	str1 = gh_scm2newstr(gh_cadr(hint),NULL);
 	str2 = gh_scm2newstr(gh_caddr(hint),NULL);
-	gmessage = g_strdup_printf (_("Move the %s on the %s."), _(str1), _(str2));
+	gmessage = g_strdup_printf (_("Move the %s on the %s."), str1, str2);
 	free (str1);
 	free (str2);
 	break;
@@ -218,7 +221,7 @@ void show_hint_dialog()
       case 2:
 	str1 = gh_scm2newstr(gh_cadr(hint),NULL);
 	str2 = gh_scm2newstr(gh_caddr(hint),NULL);
-	gmessage = g_strdup_printf (_("Move the %s on %s."), _(str1), _(str2));
+	gmessage = g_strdup_printf (_("Move the %s on %s."), str1, str2);
 	free (str1);
 	free (str2);
 	break;
@@ -226,14 +229,14 @@ void show_hint_dialog()
       case 3:
 	str1 = gh_scm2newstr(gh_cadr(hint),NULL);
 	str2 = gh_scm2newstr(gh_caddr(hint),NULL);
-	gmessage = g_strdup_printf (_("Move the %s %s."), _(str1), _(str2));
+	gmessage = g_strdup_printf (_("Move the %s %s."), str1, str2);
 	free (str1);
 	free (str2);
 	break;
 
       case 4:
 	str1 = gh_scm2newstr(gh_cadr(hint),NULL);
-	gmessage = g_strdup_printf (_("You are searching for a %s."), _(str1));
+	gmessage = g_strdup_printf (_("You are searching for a %s."), str1);
 	free (str1);
 	break;
 
