@@ -17,6 +17,10 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gdk/gdkkeysyms.h>
 
 #include "preferences.h"
@@ -62,7 +66,7 @@ static void apply_cb (GtkWidget *widget, gint pagenum, gpointer data)
 {
 	if (pagenum == -1) {
     if (t_properties->tilesize != properties->tilesize) {
-      gtk_drawing_area_size (GTK_DRAWING_AREA (drawing_area),
+      gtk_widget_set_size_request (GTK_WIDGET (drawing_area),
                              t_properties->tilesize * BOARDWIDTH,
                              t_properties->tilesize * BOARDHEIGHT);
     }
