@@ -23,16 +23,16 @@ static struct {
 
 
 
-static int num_colors[9][3] = {
-	{ 0  , 0  , 0   }, /* Black, not used */
-	{ 0  , 0  , 255 }, /* Blue  */
-	{ 0  , 160, 0   }, /* Green */
-	{ 255, 0  , 0   }, /* Red   */
-	{ 0  , 0  , 127 }, /* DarkBlue */
-	{ 160, 0  , 0   }, /* DarkRed   */
-	{ 0  , 255, 255 }, /* Cyan */
-	{ 160, 0  , 160 }, /* DarkViolet */
-	{ 0  , 0  , 0   }  /* Black */
+static guint16 num_colors[9][3] = {
+	{ 0x0000, 0x0000, 0x0000 }, /* Black, not used */
+	{ 0x0000, 0x0000, 0xffff }, /* Blue  */
+	{ 0x0000, 0xa0a0, 0x0000 }, /* Green */
+	{ 0xffff, 0x0000, 0x0000 }, /* Red   */
+	{ 0x0000, 0x0000, 0x7fff }, /* DarkBlue */
+	{ 0xa0a0, 0x0000, 0x0000 }, /* DarkRed   */
+	{ 0x0000, 0xffff, 0xffff }, /* Cyan */
+	{ 0xa0a0, 0x0000, 0xa0a0 }, /* DarkViolet */
+	{ 0x0000, 0x0000, 0x0000 }  /* Black */
 };
 
 
@@ -58,7 +58,7 @@ static inline gint cell_idx(GtkMineField *mfield, guint x, guint y)
 	return -1;
 }
 
-static void _setup_sign (sign *signp, char **data, guint minesize)
+static void _setup_sign (sign *signp, const char **data, guint minesize)
 {
 	GdkPixbuf *image;
 
@@ -81,6 +81,70 @@ static void gtk_minefield_setup_signs(GtkWidget *widget)
         _setup_sign(&mfield->mine, mine_xpm, mfield->minesize);
 }
 
+static void
+gtk_minefield_setup_numbers(GtkMineField *mfield)
+{
+	int minesize, pixel_sz, i;
+	  
+	minesize = mfield->minesize;
+
+	pixel_sz = minesize - 2;
+	if (pixel_sz > 999) pixel_sz = 999;
+	if (pixel_sz < 2)  pixel_sz = 2;
+  
+	for (i=0; i<9; i++) {
+		gchar text[2];
+		PangoLayout *layout;
+		PangoAttrList *alist;
+		PangoAttribute *attr;
+		PangoFontDescription *font_desc;
+
+		/* free an existing layout ... */
+		if (mfield->numstr[i].layout)
+			g_object_unref(mfield->numstr[i].layout);
+
+		text[0] = '0' + i;
+		text[1] = '\0';
+		layout = gtk_widget_create_pango_layout(GTK_WIDGET(mfield),
+							text);
+
+		/* set attributes for the layout */
+		alist = pango_attr_list_new();
+
+		/* do the font */
+		font_desc = pango_font_description_new();
+		pango_font_description_set_family(font_desc, "monospace");
+		pango_font_description_set_size(font_desc,
+						pixel_sz * PANGO_SCALE);
+		pango_font_description_set_weight(font_desc,PANGO_WEIGHT_BOLD);
+		attr = pango_attr_font_desc_new(font_desc);
+		pango_font_description_free(font_desc);
+
+		attr->start_index = 0;
+		attr->end_index = G_MAXUINT;
+		pango_attr_list_insert(alist, attr);
+
+		/* colour */
+		attr = pango_attr_foreground_new(num_colors[i][0],
+						 num_colors[i][1],
+						 num_colors[i][2]);
+		attr->start_index = 0;
+		attr->end_index = G_MAXUINT;
+		pango_attr_list_insert(alist, attr);
+
+		pango_layout_set_attributes(layout, alist);
+		pango_attr_list_unref(alist);
+
+		pango_layout_set_width(layout, minesize);
+		pango_layout_set_alignment(layout, PANGO_ALIGN_CENTER);
+
+		mfield->numstr[i].layout = layout;
+
+		mfield->numstr[i].dx = minesize / 2;
+		mfield->numstr[i].dy = (minesize - pixel_sz) / 2;
+	}
+}
+
 static void gtk_minefield_realize(GtkWidget *widget)
 {
         GtkMineField *mfield;
@@ -115,9 +179,6 @@ static void gtk_minefield_realize(GtkWidget *widget)
         gtk_style_set_background(widget->style, widget->window, GTK_STATE_ACTIVE);
 
         gtk_minefield_setup_signs(widget);
-
-        mfield->cc = gdk_color_context_new (gtk_widget_get_visual (widget),
-					    gtk_widget_get_colormap (widget));
 }
 
 static void gtk_minefield_unrealize (GtkWidget *widget)
@@ -129,9 +190,6 @@ static void gtk_minefield_unrealize (GtkWidget *widget)
 
 	mfield = GTK_MINEFIELD (widget);
 
-	gdk_color_context_free (mfield->cc);
-	mfield->cc = NULL;
-
 	if (GTK_WIDGET_CLASS (parent_class)->unrealize)
 		(* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
 }
@@ -210,12 +268,11 @@ static void gtk_mine_draw(GtkMineField *mfield, guint x, guint y)
 
 	if (mfield->mines[c].shown && !mfield->mines[c].mined) {
 		if ((n = mfield->mines[c].neighbours) != 0) {
-			gdk_draw_string(widget->window,
-					mfield->font,
-					mfield->numstr[n].gc,
-					x*minesize+mfield->numstr[n].dx,
-					y*minesize+mfield->numstr[n].dy,
-					mfield->numstr[n].text);
+			gdk_draw_layout(widget->window,
+					widget->style->black_gc,
+					x*minesize + mfield->numstr[n].dx,
+					y*minesize + mfield->numstr[n].dy,
+					mfield->numstr[n].layout);
 		}
 	} else if (mfield->mines[c].marked == 1) {
 		gdk_gc_set_clip_mask(widget->style->black_gc,
@@ -319,47 +376,6 @@ static gint gtk_minefield_expose(GtkWidget *widget,
 	
 	minesize = mfield->minesize;
 
-	if (mfield->numstr[0].gc == 0) {
-	        int pxlsz;
-	        char fontname[50];
-	  
-	        gtk_minefield_setup_signs(widget);
-
-	        pxlsz = minesize - 2;
-	        if (pxlsz > 999) pxlsz = 999;
-                if (pxlsz < 2)  pxlsz = 2;
-  
-                sprintf(fontname, "-bitstream-courier-bold-r-*-*-%d-*-*-*-*-*-*-*", pxlsz);
-	
-		mfield->font = gdk_font_load(fontname);
-	  
-	            /* The font used to be "-misc-fixed-bold-r-normal--13-*-*-*-*-*-*" */
-	  
-                if (!mfield->font) mfield->font = widget->style->font;
-		for (i=0; i<9; i++) {
-			mfield->numstr[i].text[0] = i+'0';
-			mfield->numstr[i].text[1] = '\0';
-			mfield->numstr[i].dx =
-				(minesize-gdk_string_width(mfield->font,
-							   mfield->numstr[i].text))/2;
-			mfield->numstr[i].dy = (minesize + 5 * pxlsz / 8) / 2;
-			mfield->numstr[i].gc = gdk_gc_new(GTK_WIDGET(mfield)->window);
-
-			color.red   = num_colors[i][0] | (num_colors[i][0] << 8);
-			color.green = num_colors[i][1] | (num_colors[i][1] << 8);
-			color.blue  = num_colors[i][2] | (num_colors[i][2] << 8);
-			color.pixel = 0; /* required! */
-
-			n = 0;
-			gdk_color_context_get_pixels (mfield->cc,
-						      &color.red, &color.green, &color.blue,
-						      1,
-						      &color.pixel,
-						      &n);
-
-			gdk_gc_set_foreground(mfield->numstr[i].gc, &color);
-		}
-	}
 
 	gtk_minefield_draw(GTK_MINEFIELD(widget), &event->area);
 
@@ -723,7 +739,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[MARKS_CHANGED_SIGNAL] =
 		gtk_signal_new("marks_changed",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, marks_changed),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -731,7 +747,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[EXPLODE_SIGNAL] =
 		gtk_signal_new("explode",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, explode),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -739,7 +755,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[LOOK_SIGNAL] =
 		gtk_signal_new("look",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, look),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -747,7 +763,7 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[UNLOOK_SIGNAL] =
 		gtk_signal_new("unlook",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, unlook),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
@@ -755,26 +771,27 @@ static void gtk_minefield_class_init (GtkMineFieldClass *class)
 	minefield_signals[WIN_SIGNAL] =
 		gtk_signal_new("win",
 			       GTK_RUN_FIRST,
-			       object_class->type,
+			       GTK_CLASS_TYPE (object_class),
 			       GTK_SIGNAL_OFFSET(GtkMineFieldClass, win),
 			       gtk_signal_default_marshaller,
 			       GTK_TYPE_NONE,
 			       0);
-
+#if 0
 	gtk_object_class_add_signals(object_class, minefield_signals, LAST_SIGNAL);
+#endif
 }
 
 static void gtk_minefield_init (GtkMineField *mfield)
 {
-#ifndef GTK_HAVE_FEATURES_1_1_4
-        GTK_WIDGET_SET_FLAGS (mfield, GTK_BASIC);
-#endif
         mfield->xsize = 0;
         mfield->ysize = 0;
-	mfield->cc = NULL;
 
         GTK_WIDGET (mfield)->requisition.width = mfield->minesize;
         GTK_WIDGET (mfield)->requisition.height = mfield->minesize;
+
+	gtk_minefield_setup_signs(GTK_WIDGET(mfield));
+
+	gtk_minefield_setup_numbers(mfield);
 }
 
 void gtk_minefield_set_size(GtkMineField *mfield, guint xsize, guint ysize)
@@ -786,8 +803,14 @@ void gtk_minefield_set_size(GtkMineField *mfield, guint xsize, guint ysize)
 		mfield->mines = g_realloc(mfield->mines,
 					  sizeof(mine)*xsize*ysize);
 	}
-	mfield->xsize = xsize;
-	mfield->ysize = ysize;
+
+	if (mfield->xsize != xsize || mfield->ysize != ysize) {
+		mfield->xsize = xsize;
+		mfield->ysize = ysize;
+		if (GTK_WIDGET_VISIBLE(mfield)) {
+			gtk_widget_queue_resize(GTK_WIDGET(mfield));
+		}
+	}
 }
 
 GtkWidget* gtk_minefield_new(void)
@@ -799,7 +822,6 @@ GtkWidget* gtk_minefield_new(void)
 	gtk_minefield_set_size(mfield, 0, 0);
 
 	mfield->cdown = -1;
-	mfield->numstr[0].gc = 0; /* Force GC generation */
 	return GTK_WIDGET(mfield);
 }
 
@@ -816,8 +838,9 @@ guint gtk_minefield_get_type ()
                                 sizeof (GtkMineFieldClass),
                                 (GtkClassInitFunc) gtk_minefield_class_init,
                                 (GtkObjectInitFunc) gtk_minefield_init,
-                                (GtkArgSetFunc) NULL,
-                                (GtkArgGetFunc) NULL,
+                                /* reserved_1 */ NULL,
+        			/* reserved_2 */ NULL,
+        			(GtkClassInitFunc) NULL,
                         };
                         
                         minefield_type = gtk_type_unique (gtk_widget_get_type (), &minefield_info);
@@ -833,11 +856,13 @@ void gtk_minefield_set_mines(GtkMineField *mfield, guint mcount, guint minesize)
 	g_return_if_fail(minesize>0);
 	
         mfield->mcount = mcount;
-        mfield->minesize = minesize;
-        mfield->numstr[0].gc = 0;
 
-	if (GTK_WIDGET_VISIBLE(mfield)) {
-		gtk_widget_queue_resize(GTK_WIDGET(mfield));
+	if (mfield->minesize != minesize) {
+		mfield->minesize = minesize;
+		gtk_minefield_setup_numbers(mfield);
+		if (GTK_WIDGET_VISIBLE(mfield)) {
+			gtk_widget_queue_resize(GTK_WIDGET(mfield));
+		}
 	}
 }
 
