@@ -481,8 +481,9 @@ int main (int argc, char **argv){
   GnomeClient *client;
 
   gnome_score_init(APPNAME);
-  bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-  textdomain(PACKAGE);
+  bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain(GETTEXT_PACKAGE);
    
   gnome_init_with_popt_table(APPNAME, VERSION, argc, argv, options, 0, NULL);
   gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnotski-icon.png");
@@ -637,11 +638,9 @@ gint configure_space(GtkWidget *widget, GdkEventConfigure *event){
 }
 
 void create_space(){
-  gtk_widget_push_visual(gdk_rgb_get_visual ());
   gtk_widget_push_colormap(gdk_rgb_get_cmap());
   space = gtk_drawing_area_new();
   gtk_widget_pop_colormap();
-  gtk_widget_pop_visual();
   gnome_app_set_contents(GNOME_APP(window),space);
   gtk_drawing_area_size(GTK_DRAWING_AREA(space),
 			TILE_SIZE*width,TILE_SIZE*height); 
@@ -692,7 +691,7 @@ void load_image(){
   if(!g_file_exists(fname)) {
     g_print(_("Could not find \'%s\' pixmap file\n"), fname); exit(1);
   }
-  image = gdk_pixbuf_new_from_file(fname);
+  image = gdk_pixbuf_new_from_file(fname, NULL);
 
   gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap, NULL, 127);
 
@@ -968,12 +967,20 @@ void about_cb(GtkWidget *widget, gpointer data){
   GtkWidget *about;
   
   const gchar *authors[] = { "Lars Rydlinge", NULL };
+  gchar *documenters[] = {
+                          NULL
+                         };
+  /* Translator credits */
+  gchar *translator_credits = _("translator_credits");
+  
   about = gnome_about_new(_(APPNAME_LONG), 
                           VERSION, 
                           "(C) 1999 Lars Rydlinge",
-			  (const char **)authors, 
 			  _("Klotski clone\n" \
 			    "(Comments to: Lars.Rydlinge@HIG.SE)"), 
-                          NULL);
+                          (const char **)authors, 
+                          (const char **)documenters,
+                          strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			  NULL);
   gtk_widget_show(about);
 }
